"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModCallbackRepentogon = void 0;
/**
 * Callbacks for REPENTOGON, an exe-hack which expands the modding API.
 *
 * @see https://repentogon.com/index.html
 */
var ModCallbackRepentogon;
(function (ModCallbackRepentogon) {
    /**
     * Fires when a collectible is being added to a player. Return `CollectibleType` to override the
     * collectible given. Alternatively, you can return an array of parameters to further modify the
     * given collectible.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `CollectibleType` provided.
     *
     * ```ts
     * function preAddCollectible(
     *   collectible: CollectibleType,
     *   charge: int,
     *   firstTime: boolean,
     *   slot: ActiveSlot,
     *   varData: int,
     *   player: EntityPlayer
     * ): CollectibleType | [CollectibleType, int, boolean, ActiveSlot, int] | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ADD_COLLECTIBLE"] = 1004] = "PRE_ADD_COLLECTIBLE";
    /**
     * Fires after a collectible is added to a player.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `CollectibleType` provided.
     *
     * ```ts
     * function postAddCollectible(
     *   collectible: CollectibleType,
     *   charge: int,
     *   firstTime: boolean,
     *   slot: ActiveSlot,
     *   varData: int,
     *   player: EntityPlayer
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_ADD_COLLECTIBLE"] = 1005] = "POST_ADD_COLLECTIBLE";
    /**
     * Fires after an entity takes damage.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function postEntityTakeDmg(
     *   entity: Entity,
     *   damage: number,
     *   damageFlags: BitFlags<DamageFlag>,
     *   source: EntityRef,
     *   damageCountdown: int
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_ENTITY_TAKE_DMG"] = 1006] = "POST_ENTITY_TAKE_DMG";
    /**
     * Behaves like `ModCallback.ENTITY_TAKE_DMG` but with additional functionality. You can return an
     * array of parameters to override how the entity takes damage.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preEntityTakeDmg(
     *   entity: Entity,
     *   damage: number,
     *   damageFlags: BitFlags<DamageFlag>,
     *   source: EntityRef,
     *   damageCountdown: int
     * ): [int, BitFlags<DamageFlag>, int] | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ENTITY_TAKE_DMG"] = 1007] = "PRE_ENTITY_TAKE_DMG";
    /**
     * Fires when a player is about to take damage. This callback fires earlier than
     * `ModCallback.ENTITY_TAKE_DAMAGE`.
     *
     * Return false to cancel the damage, which is useful for giving player invincibility that takes
     * precedence over other damage negation effects, such as Holy Mantle.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function prePlayerTakeDmg(
     *   player: EntityPlayer,
     *   damage: number,
     *   damageFlags: BitFlags<DamageFlag>,
     *   source: EntityRef,
     *   damageCountdown: int,
     * ): false | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_TAKE_DMG"] = 1008] = "PRE_PLAYER_TAKE_DMG";
    /**
     * Fires after a rock GridEntity is destroyed.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridRockDestroy(
     *   rock: GridEntityRock,
     *   gridType: GridEntityType,
     *   immediate: boolean,
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ROCK_DESTROY"] = 1011] = "POST_GRID_ROCK_DESTROY";
    /**
     * Fires when an entity is about to be hurt from a GridEntity. Return false to ignore damage.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridHurtDamage(
     *   gridEntity: GridEntityRock,
     *   tookDamage: Entity,
     *   damageAmount: int,
     *   damageFlags: BitFlags<DamageFlag>
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_HURT_DAMAGE"] = 1012] = "PRE_GRID_HURT_DAMAGE";
    /**
     * Fires after an entity is hurt from a GridEntity.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridHurtDamage(
     *   gridEntity: GridEntityRock,
     *   tookDamage: Entity,
     *   damageAmount: int,
     *   damageFlags: BitFlags<DamageFlag>
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_HURT_DAMAGE"] = 1013] = "POST_GRID_HURT_DAMAGE";
    /**
     * Fires when `HUD.Update()` is called. The game will always call the function every frame.
     *
     * ```ts
     * function hudUpdate(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["HUD_UPDATE"] = 1020] = "HUD_UPDATE";
    /**
     * Fires when `HUD.PostUpdate()` is called. The game will call the function after `HUD.Update()`
     * is called except for a few cases, such as the game being paused.
     *
     * ```ts
     * function hudPostUpdate(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["HUD_POST_UPDATE"] = 1021] = "HUD_POST_UPDATE";
    /**
     * Fires every frame the HUD is rendered.
     *
     * ```ts
     * function postHUDRender(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_HUD_RENDER"] = 1022] = "POST_HUD_RENDER";
    /**
     * Fires every frame the main menu is rendered.
     *
     * ```ts
     * function postMainMenuRender(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_MAIN_MENU_RENDER"] = 1023] = "POST_MAIN_MENU_RENDER";
    /**
     * Fires when a sound effect is about to play. Return false to prevent the sound from playing.
     * Alternatively, return an array of parameters to modify the sound before it plays.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SoundEffect` provided.
     *
     * ```ts
     * function preSFXPlay(
     *   id: SoundEffect,
     *   volume: number,
     *   frameDelay: int,
     *   pitch: number,
     *   pan: number
     * ): SoundEffect | boolean | [SoundEffect, number, int, number, number] | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_SFX_PLAY"] = 1030] = "PRE_SFX_PLAY";
    /**
     * Fires after a sound effect plays.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SoundEffect` provided.
     *
     * ```ts
     * function postSFXPlay(
     *   id: SoundEffect,
     *   volume: number,
     *   frameDelay: int,
     *   pitch: number,
     *   pan: number
     * ): SoundEffect | boolean | [SoundEffect, number, int, number, number] | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SFX_PLAY"] = 1031] = "POST_SFX_PLAY";
    /**
     * Fires when a music track is about to play. This callback is fired for both
     * `MusicManager.Play()` and `MusicManager.CrossFade()`. Use the `isFade` parameter to
     * differentiate the two.
     *
     * Return false to prevent the music from playing. Alternatively, return `Music` to override the
     * track played without changing the volume or fade rate. Return an array of parameters to further
     * modify the music track.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `Music` provided.
     *
     * ```ts
     * function preMusicPlay(
     *   id: Music,
     *   volumeOrFadeRate: number,
     *   isFade: boolean
     * ): Music | [Music, number] | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_MUSIC_PLAY"] = 1034] = "PRE_MUSIC_PLAY";
    /**
     * TODO: Add an enum for the layer.
     *
     * Fires when the currently playing music track is about to have its layer toggled. Return an
     * integer to override which layer is played. Return false to prevent the layer from being
     * toggled.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `int` provided.
     *
     * ```ts
     * function preMusicLayerToggle(
     *   layerId: int,
     *   currentState: boolean
     * ): int | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_MUSIC_LAYER_TOGGLE"] = 1035] = "PRE_MUSIC_LAYER_TOGGLE";
    /**
     * Fires when the player's head is about to render. Return a Vector to override what position the
     * head renders at. Return false to prevent the head from rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function preRenderPlayerHead(
     *   player: EntityPlayer,
     *   renderPosition: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_RENDER_PLAYER_HEAD"] = 1038] = "PRE_RENDER_PLAYER_HEAD";
    /**
     * Fires when the player's body is about to render. Return a Vector to override what position the
     * body renders at. Return false to prevent the body from rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function preRenderPlayerBody(
     *   player: EntityPlayer,
     *   renderPosition: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_RENDER_PLAYER_BODY"] = 1039] = "PRE_RENDER_PLAYER_BODY";
    /**
     * Fires when the player is about to throw an entity. Return a Vector to override the velocity of
     * the thrown entity.
     *
     * ```ts
     * function preEntityThrow(
     *   throwingPlayer: EntityPlayer,
     *   heldEntity: Entity,
     *   velocity: Vector
     * ): Vector | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ENTITY_THROW"] = 1040] = "PRE_ENTITY_THROW";
    /**
     * Fires the player throws an entity.
     *
     * ```ts
     * function postEntityThrow(
     *   throwingPlayer: EntityPlayer,
     *   heldEntity: Entity,
     *   velocity: Vector
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_ENTITY_THROW"] = 1041] = "POST_ENTITY_THROW";
    /**
     * Fires when a player's special tear type is about to be initialized, such as Azazel's brimstone.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function postPlayerLevelStatsInit(player: EntityPlayer): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_LEVEL_STATS_INIT"] = 1042] = "POST_PLAYER_LEVEL_STATS_INIT";
    /**
     * Fires when the current room is about to be changed.
     *
     * The `newLevel` parameter is true when entering a new level or exiting a run, otherwise it's
     * false.
     *
     * ```ts
     * function preRoomExit(playerWhoExited: EntityPlayer, newLevel: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ROOM_EXIT"] = 1043] = "PRE_ROOM_EXIT";
    /**
     * Fires when a level is about to be initialized.
     *
     * ```ts
     * function preLevelInit(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_LEVEL_INIT"] = 1060] = "PRE_LEVEL_INIT";
    /**
     * Fires right before the game over screen appears. Return false to cancel the death and revive
     * the player with half a heart.
     *
     * **Bug:** Much like the vanilla Revive function, this removes the current run's ability to save
     * and continue later.
     *
     * ```ts
     * function preTriggerPlayerDeath(player: EntityPlayer): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_TRIGGER_PLAYER_DEATH"] = 1050] = "PRE_TRIGGER_PLAYER_DEATH";
    /**
     * Fires when a shop is about to be restocked. Return false to cancel the restock, blocking shop
     * rerolls from restock machines or restocks from Restock altogether.
     *
     * This callback is fired for both `Room.ShopRestockFull` and `Room.ShopRestockPartial`. The
     * `partial` parameter is true if `Room.ShopRestockPartial` was called, otherwise it's false.
     *
     * ```ts
     * function preRestockShop(partial: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_RESTOCK_SHOP"] = 1070] = "PRE_RESTOCK_SHOP";
    /**
     * Fires after a shop has been restocked.
     *
     * This callback is fired for both `Room.ShopRestockFull` and `Room.ShopRestockPartial`. The
     * `partial` parameter is true if `Room.ShopRestockPartial` was called, otherwise it's false.
     *
     * ```ts
     * function postRestockShop(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_RESTOCK_SHOP"] = 1071] = "POST_RESTOCK_SHOP";
    /**
     * Fires when the current room is about to change. Return an array containing a room index and
     * dimension to override where the player ends up.
     *
     * ```ts
     * function preChangeRoom(targetRoomIdx: int, dimension: int): [int, int] | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_CHANGE_ROOM"] = 1061] = "PRE_CHANGE_ROOM";
    /**
     * Fires when a pickup has been purchased from the shop.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PickupVariant` provided.
     *
     * ```ts
     * function postPickupShopPurchase(
     *   pickup: EntityPickup,
     *   player: EntityPlayer,
     *   moneySpent: int
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PICKUP_SHOP_PURCHASE"] = 1062] = "POST_PICKUP_SHOP_PURCHASE";
    /**
     * Fires when a familiar's follower priority is about to be assigned. Return `FollowerPriority` or
     * an integer to override the familiar's follow priority.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `FamiliarVariant` provided.
     *
     * ```ts
     * function postPickupShopPurchase(
     *   familiar: EntityFamiliar
     * ): FollowerPriority | int | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["GET_FOLLOWER_PRIORITY"] = 1063] = "GET_FOLLOWER_PRIORITY";
    /**
     * Fires when a NPC is about to morph. Return an array of parameters to override what the NPC
     * morphs into. Return false to cancel the morph.
     *
     * ```ts
     * function preNPCMorph(
     *   entityType: EntityType,
     *   variant: int,
     *   subType: int,
     *   championColor: ChampionColor
     * ): [EntityType, int, int, ChampionColor] | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NPC_MORPH"] = 1212] = "PRE_NPC_MORPH";
    /**
     * Fires when a pickup is about to morph. Return an array of parameters to override what the
     * pickup morphs to. Otherwise, return false to cancel the morph.
     *
     * ```ts
     * function prePickupMorph(
     *   pickup: EntityPickup,
     *   entityType: int,
     *   variant: int,
     *   subType: int,
     *   keepPrice: boolean,
     *   keepSeed: boolean,
     *   ignoreModifiers: boolean
     * ):
     *      [EntityType, int, int, boolean, boolean, boolean]
     *      | [EntityType, int, int]
     *      | boolean
     *      | undefined
     * {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PICKUP_MORPH"] = 1213] = "PRE_PICKUP_MORPH";
    /**
     * Fires after a NPC morphs.
     *
     * ```ts
     * function postNPCMorph(
     *   previousType: EntityType,
     *   previousVariant: int,
     *   previousSubType: int
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_NPC_MORPH"] = 1214] = "POST_NPC_MORPH";
    /**
     * Fires after a pickup has been morphed.
     *
     * ```ts
     * function postPickupMorph(
     *   pickup: EntityPickup,
     *   previousType: EntityType,
     *   previousVariant: int,
     *   subType: int,
     *   keptPrice: boolean,
     *   keptSeed: int,
     *   ignoredModifiers: boolean
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PICKUP_MORPH"] = 1215] = "POST_PICKUP_MORPH";
    /**
     * Fires before the completion marks paper is rendered. Return false to prevent the sprite from
     * rendering.
     *
     * ```ts
     * function preCompletionMarksRender(
     *   completionMarksSprite: Sprite,
     *   renderPos: Vector,
     *   renderScale: Vector,
     *   playerType: PlayerType
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_COMPLETION_MARKS_RENDER"] = 1216] = "PRE_COMPLETION_MARKS_RENDER";
    /**
     * Fires after the completion marks paper is rendered.
     *
     * ```ts
     * function preCompletionMarksRender(
     *   completionMarksSprite: Sprite,
     *   renderPos: Vector,
     *   renderScale: Vector,
     *   playerType: PlayerType
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_COMPLETION_MARKS_RENDER"] = 1217] = "POST_COMPLETION_MARKS_RENDER";
    /**
     * Fires before the pause screen renders. Return false to prevent the pause screen from rendering
     * and darkening the screen.
     *
     * ```ts
     * function prePauseScreenRender(pauseBody: Sprite, pauseStats: Sprite): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PAUSE_SCREEN_RENDER"] = 1218] = "PRE_PAUSE_SCREEN_RENDER";
    /**
     * Fires after the pause screen renders.
     *
     * ```ts
     * function prePauseScreenRender(pauseBody: Sprite, pauseStats: Sprite): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PAUSE_SCREEN_RENDER"] = 1219] = "POST_PAUSE_SCREEN_RENDER";
    /**
     * Fires before a card is used. Return true to cancel the card from being used.
     *
     * ```ts
     * function preUseCard(
     *   card: CardType,
     *   player: EntityPlayer,
     *   useFlags: BitFlags<UseFlag>
     * ): boolean | undefined
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_USE_CARD"] = 1064] = "PRE_USE_CARD";
    /**
     * Fires before a pill is used. Return true to cancel the card from being used.
     *
     * ```ts
     * function preUsePill(
     *   pill: PillEffect,
     *   color: PillColor,
     *   player: EntityPlayer,
     *   useFlags: BitFlags<UseFlag>
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_USE_PILL"] = 1065] = "PRE_USE_PILL";
    /**
     * Fires before a shop item has its price assigned. Return an integer to override the price.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the integer provided.
     *
     * ```ts
     * function getShopItemPrice(
     *   variant: PickupVariant,
     *   subType: int,
     *   shopItemID: int
     * ): int {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["GET_SHOP_ITEM_PRICE"] = 1066] = "GET_SHOP_ITEM_PRICE";
    /**
     * Fires when the player's health type is being loaded. Return `PlayerHealthType` to override the
     * player's health type.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function playerGetHealthType(player: EntityPlayer): PlayerHealthType | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PLAYER_GET_HEALTH_TYPE"] = 1067] = "PLAYER_GET_HEALTH_TYPE";
    /**
     * Fires before the room clear is triggered.
     *
     * ```ts
     * function preRoomTriggerClear(playSound: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ROOM_TRIGGER_CLEAR"] = 1068] = "PRE_ROOM_TRIGGER_CLEAR";
    /**
     * Fires before a player triggers the room clear. Return false to cancel the room clear effects.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function preRenderPlayerBody(player: EntityPlayer): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_TRIGGER_ROOM_CLEAR"] = 1069] = "PRE_PLAYER_TRIGGER_ROOM_CLEAR";
    /**
     * Fires before a familiar renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the familiar.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `FamiliarVariant` provided.
     *
     * ```ts
     * function preFamiliarRender(
     *   familiar: EntityFamiliar,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_FAMILIAR_RENDER"] = 1080] = "PRE_FAMILIAR_RENDER";
    /**
     * Fires before a npc renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the npc.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preNPCRender(npc: EntityNPC, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NPC_RENDER"] = 1081] = "PRE_NPC_RENDER";
    /**
     * Fires before a player renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the player.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function prePlayerRender(player: EntityPlayer, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_RENDER"] = 1082] = "PRE_PLAYER_RENDER";
    /**
     * Fires before a pickup renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the pickup.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PickupVariant` provided.
     *
     * ```ts
     * function prePickupRender(pickup: EntityPickup, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PICKUP_RENDER"] = 1083] = "PRE_PICKUP_RENDER";
    /**
     * Fires before a tear renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the tear.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TearVariant` provided.
     *
     * ```ts
     * function preTearRender(tear: EntityTear, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_TEAR_RENDER"] = 1084] = "PRE_TEAR_RENDER";
    /**
     * Fires before a projectile renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the projectile.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `ProjectileVariant` provided.
     *
     * ```ts
     * function preProjectileRender(
     *   projectile: ProjectileVariant,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PROJECTILE_RENDER"] = 1085] = "PRE_PROJECTILE_RENDER";
    /**
     * Fires before a knife renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the knife.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `KnifeVariant` provided.
     *
     * ```ts
     * function preKnifeRender(knife: EntityKnife, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_KNIFE_RENDER"] = 1086] = "PRE_KNIFE_RENDER";
    /**
     * Fires before a effect renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the effect.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EffectVariant` provided.
     *
     * ```ts
     * function preEffectRender(effect: EntityEffect, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_EFFECT_RENDER"] = 1087] = "PRE_EFFECT_RENDER";
    /**
     * Fires before a bomb renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the bomb.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `BombVariant` provided.
     *
     * ```ts
     * function preBombRender(bomb: EntityBomb, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_BOMB_RENDER"] = 1088] = "PRE_BOMB_RENDER";
    /**
     * Fires before a slot renders. Return a Vector to modify the rendered sprite's offset.
     * Alternatively, return false to cancel rendering the slot.
     *
     * Canceling this callback will not stop rendering of entity shadows. This is being investigated,
     * but in the meantime call `Entity.SetShadowSize(0)` on the entity in `ModCallback.POST_UPDATE`.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function preSlotRender(slot: EntitySlot, offset: Vector): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_SLOT_RENDER"] = 1089] = "PRE_SLOT_RENDER";
    /**
     * Fires after a slot renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotRender(slot: EntitySlot, offset: Vector): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_RENDER"] = 1090] = "POST_SLOT_RENDER";
    /**
     * Fires before a GridEntity is spawned outside of room initialization. Return false to cancel
     * spawning the grid. Alternatively, return an array of parameters or a GridEntityDesc to override
     * the GridEntity spawned.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntitySpawn(
     *   gridEntityType: GridEntityType,
     *   variant: int,
     *   varData: int,
     *   gridIndex: int,
     *   spawnSeed: Seed,
     *   desc: GridEntityDesc
     * ): [GridEntityType, int, int, Seed] | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_SPAWN"] = 1100] = "PRE_GRID_ENTITY_SPAWN";
    /**
     * Fires after a GridEntity is spawned outside of room initialization.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntitySpawn(
     *   gridEntityType: GridEntityType,
     *   variant: int,
     *   varData: int,
     *   gridIndex: int,
     *   spawnSeed: Seed,
     *   desc: GridEntityDesc
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_SPAWN"] = 1101] = "POST_GRID_ENTITY_SPAWN";
    /**
     * Fires before a collectible belonging to a player has its max charges loaded. Return an integer
     * to override the item's chargebar.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `CollectibleType` provided.
     *
     * ```ts
     * function playerGetActiveMaxCharge(
     *   collectible: Collectible,
     *   player: EntityPlayer,
     *   varData: int
     * ): int | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PLAYER_GET_ACTIVE_MAX_CHARGE"] = 1072] = "PLAYER_GET_ACTIVE_MAX_CHARGE";
    /**
     * Fires before a collectible belonging to a player has its minimum usable charges loaded. If the
     * item has the minimum amount of charge, it will show the white outline around the chargebar
     * sprite.
     *
     * Return an integer to override the minimum charges.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `CollectibleType` provided.
     *
     * ```ts
     * function playerGetActiveMinUsableCharge(slot: ActiveSlot): int | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PLAYER_GET_ACTIVE_MIN_USABLE_CHARGE"] = 1073] = "PLAYER_GET_ACTIVE_MIN_USABLE_CHARGE";
    /**
     * Fires every frame. Return an integer to override the player's heart limit.
     *
     * You can set the limit to any arbitrary amount but the game can only render up to 4 lines of
     * hearts in the HUD. However, even if they're not visible, the hearts still work properly.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function playerGetHeartLimit(
     *   player: EntityPlayer,
     *   heartLimit: int,
     *   isKeeper: boolean
     * ): int undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PLAYER_GET_HEART_LIMIT"] = 1074] = "PLAYER_GET_HEART_LIMIT";
    /**
     * Returns every an item overlay is rendered.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GiantbookType` provided.
     *
     * ```ts
     * function postItemOverlayUpdate(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_ITEM_OVERLAY_UPDATE"] = 1075] = "POST_ITEM_OVERLAY_UPDATE";
    /**
     * Fires before an item overlay is shown. Return `GiantBookType` to override the overlay shown.
     * Alternatively, return true to cancel the item overlay.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GiantbookType` provided.
     *
     * ```ts
     * function preItemOverlayShow(
     *   giantbookType: GiantbookType,
     *   delay: int,
     *   player: EntityPlayer
     * ): GiantbookType | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ITEM_OVERLAY_SHOW"] = 1076] = "PRE_ITEM_OVERLAY_SHOW";
    /**
     * TODO: Document me!
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function postPlayerNewRoomTempEffects(player: EntityPlayer): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_NEW_ROOM_TEMP_EFFECTS"] = 1077] = "POST_PLAYER_NEW_ROOM_TEMP_EFFECTS";
    /**
     * TODO: Document me!
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function postPlayerNewLevel(player: EntityPlayer): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_NEW_LEVEL"] = 1078] = "POST_PLAYER_NEW_LEVEL";
    /**
     * Fires every frame. Return a `MultiShotParams` object to change the properties of the player's
     * shooting behavior in regards to the MultiShotParams object.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function postPlayerGetMultiShotParams(player: EntityPlayer): MultiShotParams | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_GET_MULTI_SHOT_PARAMS"] = 1251] = "POST_PLAYER_GET_MULTI_SHOT_PARAMS";
    /**
     * Fires before a spritesheet in a sprite is replaced.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the anm2 file name provided.
     *
     * ```ts
     * function preReplaceSpritesheet(layerId: int, fileName: string): string | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_REPLACE_SPRITESHEET"] = 1116] = "PRE_REPLACE_SPRITESHEET";
    /**
     * Fires after a spritesheet in a sprite is replaced.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the anm2 file name provided.
     *
     * ```ts
     * function postReplaceSpritesheet(layerId: int, fileName: string): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_REPLACE_SPRITESHEET"] = 1117] = "POST_REPLACE_SPRITESHEET";
    /**
     * Fires at the start of planetarium calculation. Before calculating, the game first checks if the
     * current floor is valid to spawn a planetarium. If the current floor is invalid, all further
     * calculation (and thus, all further callbacks) will be canceled.
     *
     * By default, planetariums cannot spawn past Depths 2, or Womb 2 with Telescope Lens.
     *
     * This callback can be used, for example, to add custom planetarium spawn rules on custom floors,
     * or to add new items like Telescope Lens which can augment the rules.
     *
     * Return false to bypass the stage penalty.
     *
     * ```ts
     * function prePlanetariumStagePenalty(): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLANETARIUM_APPLY_STAGE_PENALTY"] = 1110] = "PRE_PLANETARIUM_APPLY_STAGE_PENALTY";
    /**
     * After `ModCallback.PRE_PLANETARIUM_APPLY_STAGE_PENALTY` is fired and the stage is valid for a
     * planetarium to generate, the callback checks if a planetarium has been entered before. If so,
     * the chance is locked at 1%, or 10% with Telescope Lens.
     *
     * Return false to bypass the planetarium enter penalty.
     *
     * This callback can be used, for example, to add custom planetarium spawn rules on custom floors,
     * or to add new items like Telescope Lens which can augment the rules.
     *
     * Return false to bypass the stage penalty.
     *
     * ```ts
     * function prePlanetariumApplyPlanetariumPenalty(): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLANETARIUM_APPLY_PLANETARIUM_PENALTY"] = 1111] = "PRE_PLANETARIUM_APPLY_PLANETARIUM_PENALTY";
    /**
     * After ensuring planetariums haven't been entered before, the game then checks how many treasure
     * rooms entered is greater than or equal to the current stage number, the chance will be locked
     * at 1%, or 10% with Telescope Lens.
     *
     * If you're looking to add an item like Telescope Lens which modifies the base chance, look at
     * `ModCallback.PRE_PLANETARIUM_APPLY_TELESCOPE_LENS` instead.
     *
     * Return false to bypass the planetarium treasure room penalty entirely, meaning the game will
     * act as if no treasure rooms have been entered. Alternatively, return an integer to modify how
     * many treasure rooms the game will believe has been entered.
     *
     * ```ts
     * function prePlanetariumApplyTreasurePenalty(
     *   treasureRoomsEntered: int
     * ): boolean | int | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLANETARIUM_APPLY_TREASURE_PENALTY"] = 1112] = "PRE_PLANETARIUM_APPLY_TREASURE_PENALTY";
    /**
     * After checking the amount of treasure rooms entered, the game applies flat item chances. This
     * is where Crystal Ball, Magic 8 Ball, and Sausage's chances get added, as well as Telescope
     * Lens' additional 15% chance.
     *
     * If you're looking to add an item like Telescope Lens which modifies the base chance, have a
     * look at `ModCallback.PRE_PLANETARIUM_APPLY_TELESCOPE_LENS` instead.
     *
     * Return a number to modify the chance in this step of the calculation.
     *
     * ```ts
     * function prePlanetariumApplyItems(chance: number): number | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLANETARIUM_APPLY_ITEMS"] = 1113] = "PRE_PLANETARIUM_APPLY_ITEMS";
    /**
     * After all previous planetarium chance calculations callbacks fire, Telescope Lens adds an
     * additional 9% chance to the base chance, bringing the base generation chance at 10%.
     *
     * Return a number to modify the chance in this step of the calculation.
     *
     * ```ts
     * function prePlanetariumApplyTelescopeLens(chance: number): number | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLANETARIUM_APPLY_TELESCOPE_LENS"] = 1114] = "PRE_PLANETARIUM_APPLY_TELESCOPE_LENS";
    /**
     * This will override all previous calculation values, ultimately dictating the planetarium
     * chance. Return a number to modify the chance.
     *
     * ```ts
     * function postPlanetariumCalculate(chance: number): number | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLANETARIUM_CALCULATE"] = 1115] = "POST_PLANETARIUM_CALCULATE";
    /**
     * Fires after an EntitySlot initializes.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotUpdate(slot: EntitySlot): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_INIT"] = 1121] = "POST_SLOT_INIT";
    /**
     * Fires after an EntitySlot updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotUpdate(slot: EntitySlot): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_UPDATE"] = 1122] = "POST_SLOT_UPDATE";
    /**
     * Fires before pickups are spawned from blowing up the slot. Return false to prevent the
     * collectibles from spawning.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function preSlotCreateExplosionDrops(slot: EntitySlot): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_SLOT_CREATE_EXPLOSION_DROPS"] = 1123] = "PRE_SLOT_CREATE_EXPLOSION_DROPS";
    /**
     * Fires after pickups are spawned from blowing up the slot.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotCreateExplosionDrops(slot: EntitySlot): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_CREATE_EXPLOSION_DROPS"] = 1124] = "POST_SLOT_CREATE_EXPLOSION_DROPS";
    /**
     * Fires before the slot's prize collectible is set. This is used by Shell Game and Hell Game.
     *
     * Return a CollectibleType to override what the slot will pay out with.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function preSlotSetPrizeCollectible(slot: EntitySlot): Collectible | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_SLOT_SET_PRIZE_COLLECTIBLE"] = 1125] = "PRE_SLOT_SET_PRIZE_COLLECTIBLE";
    /**
     * Fires after the slot's prize collectible is set. This is used by Shell Game and Hell Game.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotSetPrizeCollectible(slot: EntitySlot): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_SET_PRIZE_COLLECTIBLE"] = 1126] = "POST_SLOT_SET_PRIZE_COLLECTIBLE";
    /**
     * Fires when the game starts to tally up vanilla items for devil deal calculation. This is called
     * before the stage penalty.
     *
     * Most items that affect devil deal chances perform their changes here.
     *
     * Return a number to modify the chance in this step of calculation.
     *
     * ```ts
     * function preDevilApplyItems(): number {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_DEVIL_APPLY_ITEMS"] = 1130] = "PRE_DEVIL_APPLY_ITEMS";
    /**
     * Fires after `RepentogonCallback.PRE_DEVIL_APPLY_ITEMS`, where the game calculates the stage
     * penalty.
     *
     * If a deal is spawned anywhere on the previous two floors, the game decays the resulting chance
     * by 50% or 25% depending on the amount of deals taken.
     *
     * Note that even though the game displays a value of ~66% or ~33% for the 50% and 25% chances
     * respectively, this is because devil chance is not clamped to a value between 0 and 1, and
     * "100%" without items generally means a value of ~133%.
     *
     * Return false to bypass the stage penalty.
     *
     * Return a number to modify the chance in this step of calculation.
     *
     * ```ts
     * function preDevilApplyStagePenalty(): boolean {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_DEVIL_APPLY_STAGE_PENALTY"] = 1131] = "PRE_DEVIL_APPLY_STAGE_PENALTY";
    /**
     * Fires after `RepentogonCallback.PRE_DEVIL_APPLY_STAGE_PENALTY`, where the game calculates items
     * which bypass the stage penalty like Goat Head and Eucharist.
     *
     * Return a number to modify the chance in this step of the calculation.
     *
     * ```ts
     * function preDevilApplySpecialItems(): int {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_DEVIL_APPLY_SPECIAL_ITEMS"] = 1132] = "PRE_DEVIL_APPLY_SPECIAL_ITEMS";
    /**
     * Fires after `RepentogonCallback.PRE_DEVIL_APPLY_SPECIAL_ITEMS`. This dictates the final devil
     * deal chance.
     *
     * Return a number to modify the chance.
     *
     * ```ts
     * function postDevilCalculate(): int {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_DEVIL_CALCULATE"] = 1133] = "POST_DEVIL_CALCULATE";
    /**
     * Fires before a player gets a completion mark. Return false to prevent the mark from being
     * given.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function preCompletionMarkGet(
     *   completionType: CompletionType,
     *   playerType: PlayerType
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_COMPLETION_MARK_GET"] = 1047] = "PRE_COMPLETION_MARK_GET";
    /**
     * Fires after a player gets a completion mark.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function postCompletionMarkGet(completionType: CompletionType, playerType: PlayerType): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_COMPLETION_MARK_GET"] = 1048] = "POST_COMPLETION_MARK_GET";
    /**
     * Fires before a completion event is triggered. Return false to cancel the event, preventing all
     * marks and completion event related stuff to trigger for all players.
     *
     * ```ts
     * function preCompletionEvent(completionType: CompletionType): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_COMPLETION_EVENT"] = 1049] = "PRE_COMPLETION_EVENT";
    /**
     * Behaves the same as `ModCallback.POST_USE_PILL` with the addition of PillColor being passed as
     * an argument.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PillEffect` provided.
     *
     * ```ts
     * function postUsePill(
     *   effect: PillEffect,
     *   player: EntityPlayer,
     *   flags: BitFlags<UseFlag>,
     *   color: PillColor
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_USE_PILL"] = 1001] = "POST_USE_PILL";
    /**
     * Fires after an active item is rendered on the screen.
     *
     * ```ts
     * function postPlayerHUDRenderActiveItem(
     *   player: EntityPlayer,
     *   slot: ActiveSlot,
     *   offset: Vector,
     *   alpha: number
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_HUD_RENDER_ACTIVE_ITEM"] = 1079] = "POST_PLAYER_HUD_RENDER_ACTIVE_ITEM";
    /**
     * Fires after the health HUD is rendered.
     *
     * ```ts
     * function postPlayerHUDRenderHearts(
     *   offset: Vector,
     *   heartsSprite: Sprite,
     *   position: Vector
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_HUD_RENDER_HEARTS"] = 1091] = "POST_PLAYER_HUD_RENDER_HEARTS";
    /**
     * Fires every frame. Return a number to modify the lighting's alpha. This is generally between 0
     * and 1 but you can technically go higher than this.
     *
     * ```ts
     * function preGetLightingAlpha(originalAlpha: number): number | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GET_LIGHTING_ALPHA"] = 1150] = "PRE_GET_LIGHTING_ALPHA";
    /**
     * TODO: Document me fully! Return a Vector to override the offset. Alternatively, return false to
     * stop the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preRenderGridLighting(
     *   gridEntity: GridEntity,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_RENDER_GRID_LIGHTING"] = 1151] = "PRE_RENDER_GRID_LIGHTING";
    /**
     * TODO: Document me fully! Return a Vector to override the offset. Alternatively, return false to
     * stop the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preRenderEntityLighting(
     *   entity: Entity,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_RENDER_ENTITY_LIGHTING"] = 1152] = "PRE_RENDER_ENTITY_LIGHTING";
    /**
     * TODO: Document me fully!
     *
     * ```ts
     * function prePlayerApplyInnateCollectibleNum(
     *   modCount: int,
     *   player: EntityPlayer,
     *   collectible: CollectibleType,
     *   onlyCountTrueItems: boolean
     * ): int | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_APPLY_INNATE_COLLECTIBLE_NUM"] = 1092] = "PRE_PLAYER_APPLY_INNATE_COLLECTIBLE_NUM";
    /**
     * Fires before the jingle track plays. Return `Music` to change the track. Alternatively, return
     * false to prevent the track from playing.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `Music` provided.
     *
     * ```ts
     * function preMusicPlayJingle(id: Music): boolean | Music | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_MUSIC_PLAY_JINGLE"] = 1094] = "PRE_MUSIC_PLAY_JINGLE";
    /**
     * Fires after a collectible has been removed.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `CollectibleType` provided.
     *
     * ```ts
     * function postTriggerCollectibleRemoved(
     *   player: EntityPlayer,
     *   collectible: CollectibleType
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_TRIGGER_COLLECTIBLE_REMOVED"] = 1095] = "POST_TRIGGER_COLLECTIBLE_REMOVED";
    /**
     * Fires after a trinket has been added to a player.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TrinketType` provided.
     *
     * ```ts
     * function postTriggerTrinketAdded(
     *   player: EntityPlayer,
     *   trinketType: TrinketType,
     *   firstTimePickingUp: boolean
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_TRIGGER_TRINKET_ADDED"] = 1096] = "POST_TRIGGER_TRINKET_ADDED";
    /**
     * Fires after a trinket has been removed from a player.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TrinketType` provided.
     *
     * ```ts
     * function postTriggerTrinketRemoved(
     *   player: EntityPlayer,
     *   trinketType: TrinketType,
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_TRIGGER_TRINKET_REMOVED"] = 1097] = "POST_TRIGGER_TRINKET_REMOVED";
    /**
     * TODO: Document me!
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `WeaponType` provided.
     *
     * ```ts
     * function postTriggerWeaponFired(
     *   fireDirection: Vector,
     *   fireAmount: int,
     *   owner: Entity
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_TRIGGER_WEAPON_FIRED"] = 1098] = "POST_TRIGGER_WEAPON_FIRED";
    /**
     * Fires after the level's layout has been generated. You can access the LevelGenerator class from
     * here.
     *
     * ```ts
     * function postLevelLayoutGenerated(levelGenerator: LevelGenerator): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_LEVEL_LAYOUT_GENERATED"] = 1099] = "POST_LEVEL_LAYOUT_GENERATED";
    /**
     * Fires every frame the nightmare scene is rendering.
     *
     * ```ts
     * function postNightmareSceneRender(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_NIGHTMARE_SCENE_RENDER"] = 1102] = "POST_NIGHTMARE_SCENE_RENDER";
    /**
     * Fires when the nightmare scene is shown.
     *
     * ```ts
     * function postNightmareSceneShow(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_NIGHTMARE_SCENE_SHOW"] = 1103] = "POST_NIGHTMARE_SCENE_SHOW";
    /**
     * Fires when the game selects which stage to load, usually when the player enters a trapdoor.
     * Return an array containing the LevelStage and StageType respectively to override which level
     * the player ends up on.
     *
     * ```ts
     * function preLevelSelect(
     *   level: LevelStage,
     *   stageType: StageType
     * ): [LevelStage?, StageType?] | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["MC_PRE_LEVEL_SELECT"] = 1104] = "MC_PRE_LEVEL_SELECT";
    /**
     * TODO: Document me!
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `WeaponType` provided.
     *
     * ```ts
     * function postWeaponFire(
     *   weapon: Weapon,
     *   fireDirection: Vector,
     *   isShooting: boolean,
     *   isInterpolated: boolean
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_WEAPON_FIRE"] = 1105] = "POST_WEAPON_FIRE";
    /**
     * Fires before a player uses a bomb. Return false to stop the player from using a bomb.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function prePlayerUseBomb(player: EntityPlayer): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_USE_BOMB"] = 1220] = "PRE_PLAYER_USE_BOMB";
    /**
     * Fires after a player uses a bomb.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function postPlayerUseBomb(player: EntityPlayer, bomb: EntityBomb): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_USE_BOMB"] = 1221] = "POST_PLAYER_USE_BOMB";
    /**
     * Fires before a NPC picks its target, such as when `EntityNPC.GetPlayerTarget()` is called.
     * Return an Entity to override what the NPC targets instead.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preNPCPickTarget(
     *   npc: EntityNPC,
     *   currentTarget: Entity | undefined
     * ): Entity | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NPC_PICK_TARGET"] = 1222] = "PRE_NPC_PICK_TARGET";
    /**
     * Acts like `ModCallback.PRE_PLAYER_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function prePlayerCollision(
     *   player: EntityPlayer,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_COLLISION"] = 1230] = "PRE_PLAYER_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerVariant` provided.
     *
     * ```ts
     * function postPlayerCollision(player: EntityPlayer, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PLAYER_COLLISION"] = 1231] = "POST_PLAYER_COLLISION";
    /**
     * Acts like `ModCallback.PRE_TEAR_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TearVariant` provided.
     *
     * ```ts
     * function preTearCollision(
     *   tear: EntityTear,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_TEAR_COLLISION"] = 1232] = "PRE_TEAR_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TearVariant` provided.
     *
     * ```ts
     * function postTearCollision(tear: EntityTear, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_TEAR_COLLISION"] = 1233] = "POST_TEAR_COLLISION";
    /**
     * Acts like `ModCallback.PRE_FAMILIAR_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `FamiliarVariant` provided.
     *
     * ```ts
     * function preFamiliarCollision(
     *   familiar: EntityFamiliar,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_FAMILIAR_COLLISION"] = 1234] = "PRE_FAMILIAR_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `FamiliarVariant` provided.
     *
     * ```ts
     * function postFamiliarCollision(familiar: EntityFamiliar, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FAMILIAR_COLLISION"] = 1235] = "POST_FAMILIAR_COLLISION";
    /**
     * Acts like `ModCallback.PRE_BOMB_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `BombVariant` provided.
     *
     * ```ts
     * function preBombCollision(
     *   bomb: EntityBomb,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_BOMB_COLLISION"] = 1236] = "PRE_BOMB_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `BombVariant` provided.
     *
     * ```ts
     * function postBombCollision(bomb: EntityBomb, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_BOMB_COLLISION"] = 1237] = "POST_BOMB_COLLISION";
    /**
     * Acts like `ModCallback.PRE_PICKUP_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PickupVariant` provided.
     *
     * ```ts
     * function prePickupCollision(
     *   pickup: EntityPickup,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PICKUP_COLLISION"] = 1238] = "PRE_PICKUP_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PickupVariant` provided.
     *
     * ```ts
     * function postPickupCollision(pickup: EntityPickup, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PICKUP_COLLISION"] = 1239] = "POST_PICKUP_COLLISION";
    /**
     * Fires when the player collides with a slot.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function preSlotCollision(
     *   slot: EntitySlot,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_SLOT_COLLISION"] = 1240] = "PRE_SLOT_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `SlotVariant` provided.
     *
     * ```ts
     * function postSlotCollision(slot: EntitySlot, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SLOT_COLLISION"] = 1241] = "POST_SLOT_COLLISION";
    /**
     * Acts like `ModCallback.PRE_KNIFE_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `KnifeVariant` provided.
     *
     * ```ts
     * function preKnifeCollision(
     *   knife: EntityKnife,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_KNIFE_COLLISION"] = 1242] = "PRE_KNIFE_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `KnifeVariant` provided.
     *
     * ```ts
     * function postKnifeCollision(knife: EntityKnife, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_KNIFE_COLLISION"] = 1243] = "POST_KNIFE_COLLISION";
    /**
     * Acts like `ModCallback.PRE_PROJECTILE_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `ProjectileVariant` provided.
     *
     * ```ts
     * function preProjectileCollision(
     *   projectile: EntityProjectile,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PROJECTILE_COLLISION"] = 1244] = "PRE_PROJECTILE_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `ProjectileVariant` provided.
     *
     * ```ts
     * function postProjectileCollision(
     *   projectile: EntityProjectile,
     *   collider: Entity,
     *   low: boolean
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_PROJECTILE_COLLISION"] = 1245] = "POST_PROJECTILE_COLLISION";
    /**
     * Acts like `ModCallback.PRE_NPC_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preNPCCollision(
     *   npc: EntityNPC,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NPC_COLLISION"] = 1246] = "PRE_NPC_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function postNPCCollision(npc: EntityNPC, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_NPC_COLLISION"] = 1247] = "POST_NPC_COLLISION";
    /**
     * Acts like `ModCallback.PRE_LASER_COLLISION` except it supports returning a dictionary.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `LaserVariant` provided.
     *
     * ```ts
     * function preLaserCollision(
     *   laser: EntityLaser,
     *   collider: Entity,
     *   low: boolean
     * ): boolean | { Collide: boolean, SkipCollisionEffects: boolean } | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_LASER_COLLISION"] = 1248] = "PRE_LASER_COLLISION";
    /**
     * Fires after the on-collision code of the entity was ran, assuming it wasn't skipped in its
     * pre-collision callback.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `LaserVariant` provided.
     *
     * ```ts
     * function postLaserCollision(laser: EntityLaser, collider: Entity, low: boolean): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_LASER_COLLISION"] = 1249] = "POST_LASER_COLLISION";
    /**
     * Fires every time the console input changes whenever a function with the
     * `AutocompleteType.CUSTOM` enum is being entered into the console.
     *
     * You can return an array which can hold up to two strings, with the first string being the
     * parameter for the command's autocomplete and the second being a description. The description
     * can be used in autocomplete as well, however pressing the tab key will properly autocomplete
     * the ID, not the description (Think the `giveitem` command as an example; `c1` would be The Sad
     * Onion's "parameter" and "The Sad Onion" would be the description, and both work. Pressing the
     * tab key would turn the command into `give c1`).
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the string provided.
     *
     * ```ts
     * function consoleAutocomplete(command: string, params: string): [string, string?] {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["CONSOLE_AUTOCOMPLETE"] = 1120] = "CONSOLE_AUTOCOMPLETE";
    /**
     * TODO: Document me!
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `PlayerType` provided.
     *
     * ```ts
     * function playerInitPreLevelInitStates(player: EntityPlayer): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PLAYER_INIT_PRE_LEVEL_INIT_STATS"] = 1127] = "PLAYER_INIT_PRE_LEVEL_INIT_STATS";
    /**
     * Fires before a new room is loaded.
     *
     * ```ts
     * function preNewRoom(room: Room, descriptor: RoomDescriptor): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NEW_ROOM"] = 1200] = "PRE_NEW_ROOM";
    /**
     * Fires before the game forcefully ends upon defeating Mega Satan. Return true to prevent the
     * ending, guaranteeing a portal to the Void while retaining the completion marks.
     *
     * ```ts
     * function preMegaSatanEnding(): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_MEGA_SATAN_ENDING"] = 1201] = "PRE_MEGA_SATAN_ENDING";
    /**
     * Fires after all Lua scripts have been loaded.
     *
     * ```ts
     * function postModsLoaded(): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_MODS_LOADED"] = 1210] = "POST_MODS_LOADED";
    /**
     * Fires after an item overlay is shown.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GiantBook` provided.
     *
     * ```ts
     * function postItemOverlayShow(giantBook: GiantBook, delay: int, player: EntityPlayer): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_ITEM_OVERLAY_SHOW"] = 1134] = "POST_ITEM_OVERLAY_SHOW";
    /**
     * Fires before a room is placed onto the level. Return a room config to replace the room that
     * will be place. It must have the same shape and the new available door slots must be compatible
     * with the original room doors.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GiantBook` provided.
     *
     * ```ts
     * function preLevelPlaceRoom(
     *   slot: LevelGeneratorRoom,
     *   roomConfig: RoomConfig,
     *   seed: Seed
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_LEVEL_PLACE_ROOM"] = 1137] = "PRE_LEVEL_PLACE_ROOM";
    /**
     * Fires before a npc is split, such as when the Meat Cleaver item is used. Return true to prevent
     * the split. Alternatively, false to allow the split even if the npc is normally blacklisted by
     * the game.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `EntityType` provided.
     *
     * ```ts
     * function preNPCSplit(npc: EntityNPC, isBlacklisted: boolean): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_NPC_SPLIT"] = 1191] = "PRE_NPC_SPLIT";
    /**
     * Fires during room initialization when grid entities from the layout are being spawned.
     *
     * Return false to cancel spawning the grid entity. Alternatively, return an array containing the
     * GridEntityType, variant, var data, and spawn seed to override it.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preRoomGridEntitySpawn(
     *   gridEntityType: GridEntityType,
     *   variant: int,
     *   varData: int,
     *   gridIndex: int,
     *   spawnSeed: Seed
     * ): boolean | [GridEntityType, int, int, int, Seed] | undefined
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_ROOM_GRID_ENTITY_SPAWN"] = 1192] = "PRE_ROOM_GRID_ENTITY_SPAWN";
    /**
     * Fires after a familiar fires a projectile.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `FamiliarVariant` provided.
     *
     * ```ts
     * function postFamiliarFireProjectile(tear: EntityTear): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FAMILIAR_FIRE_PROJECTILE"] = 1252] = "POST_FAMILIAR_FIRE_PROJECTILE";
    /**
     * Fires after a player fires a Dr. Fetus bomb.
     *
     * ```ts
     * function postFireBomb(bomb: EntityBomb): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_BOMB"] = 1253] = "POST_FIRE_BOMB";
    /**
     * Fires after a player fires The Forgotten's bone club.
     *
     * This is only called when the club is initially spawned, not when swung or charged and shot.
     *
     * ```ts
     * function postFireBoneClub(club: EntityKnife): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_BONE_CLUB"] = 1254] = "POST_FIRE_BONE_CLUB";
    /**
     * Fires after a player fires a brimstone laser. This is also fired for delayed brimstone.
     *
     * ```ts
     * function postFireBrimstone(brimstone: EntityLaser): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_BRIMSTONE"] = 1255] = "POST_FIRE_BRIMSTONE";
    /**
     * Fires after a player fires a brimstone ball.
     *
     * ```ts
     * function postFireBrimstoneBall(ball: EntityEffect): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_BRIMSTONE_BALL"] = 1256] = "POST_FIRE_BRIMSTONE_BALL";
    /**
     * Fires after a player fires a knife from Mom's Knife.
     *
     * This is only fired when the knife is initially spawned, not when charged and shot.
     *
     * ```ts
     * function postFireKnife(knife: EntityKnife): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_KNIFE"] = 1257] = "POST_FIRE_KNIFE";
    /**
     * Fires after a player swings the Spirit Sword.
     *
     * ```ts
     * function postFireSword(sword: EntityKnife): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_SWORD"] = 1258] = "POST_FIRE_SWORD";
    /**
     * Fires after a player fires a Tech laser.
     *
     * ```ts
     * function postFireTechLaser(laser: EntityLaser): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_TECH_LASER"] = 1259] = "POST_FIRE_TECH_LASER";
    /**
     * Fires after a player fires a Tech X laser.
     *
     * ```ts
     * function postFireTechXLaser(laser: EntityLaser): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FIRE_TECH_X_LASER"] = 1260] = "POST_FIRE_TECH_X_LASER";
    /**
     * Fires after a familiar fires a brimstone laser.
     *
     * ```ts
     * function postFamiliarFireBrimstone(brimstone: EntityLaser): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FAMILIAR_FIRE_BRIMSTONE"] = 1261] = "POST_FAMILIAR_FIRE_BRIMSTONE";
    /**
     * Fires after a familiar fires a tech laser.
     *
     * ```ts
     * function postFamiliarFireTechLaser(laser: EntityLaser): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_FAMILIAR_FIRE_TECH_LASER"] = 1262] = "POST_FAMILIAR_FIRE_TECH_LASER";
    /**
     * TODO: Document me fully! Return true to allow the entity to respawn.
     *
     * ```ts
     * function getIsPersistentRoomEntity(
     *   entityType: EntityType,
     *   variant: int
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["GET_IS_PERSISTENT_ROOM_ENTITY"] = 1263] = "GET_IS_PERSISTENT_ROOM_ENTITY";
    /**
     * Fires before the trinket is rendered. Return an array containing the position and scale
     * respectively to override how the trinket hud is rendered. Alternatively, return true to prevent
     * it from rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `TrinketSlot` provided.
     *
     * ```ts
     * function prePlayerHudTrinketRender(
     *   slot: TrinketSlot,
     *   position: Vector,
     *   scale: number,
     *   player: EntityPlayer
     * ): [Vector, number] | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_PLAYER_HUD_TRINKET_RENDER"] = 1264] = "PRE_PLAYER_HUD_TRINKET_RENDER";
    /**
     * Fires before the decoration grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityDecorationUpdate(
     *   decoration: GridEntityDecoration
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_DECORATION_UPDATE"] = 1400] = "PRE_GRID_ENTITY_DECORATION_UPDATE";
    /**
     * Fires after the decoration grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityDecorationUpdate(decoration: GridEntityDecoration): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_DECORATION_UPDATE"] = 1401] = "POST_GRID_ENTITY_DECORATION_UPDATE";
    /**
     * Fires before the door grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityDoorUpdate(door: GridEntityDoor): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_DOOR_UPDATE"] = 1402] = "PRE_GRID_ENTITY_DOOR_UPDATE";
    /**
     * Fires after the door grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityDoorUpdate(door: GridEntityDoor): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_DOOR_UPDATE"] = 1403] = "POST_GRID_ENTITY_DOOR_UPDATE";
    /**
     * Fires before the fire grid entity updates. Return false to cancel the update.
     *
     * Fire grid entities are largely unused, and in most cases you'll want to target the EntityNPC
     * fireplaces.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityFireUpdate(fire: GridEntityFire): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_FIRE_UPDATE"] = 1404] = "PRE_GRID_ENTITY_FIRE_UPDATE";
    /**
     * Fires after the fire grid entity updates.
     *
     * Fire grid entities are largely unused, and in most cases you'll want to target the EntityNPC
     * fireplaces.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityFireUpdate(fire: GridEntityFire): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_FIRE_UPDATE"] = 1405] = "POST_GRID_ENTITY_FIRE_UPDATE";
    /**
     * Fires before the gravity grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityGravityUpdate(gravity: GridEntityGravity): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_GRAVITY_UPDATE"] = 1406] = "PRE_GRID_ENTITY_GRAVITY_UPDATE";
    /**
     * Fires after the gravity grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityGravityUpdate(gravity: GridEntityGravity): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_GRAVITY_UPDATE"] = 1407] = "POST_GRID_ENTITY_GRAVITY_UPDATE";
    /**
     * Fires before the lock grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityLockUpdate(lock: GridEntityLock): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_LOCK_UPDATE"] = 1408] = "PRE_GRID_ENTITY_LOCK_UPDATE";
    /**
     * Fires after the lock grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityLockUpdate(lock: GridEntityLock): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_LOCK_UPDATE"] = 1409] = "POST_GRID_ENTITY_LOCK_UPDATE";
    /**
     * Fires before the pit grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPitUpdate(pit: GridEntityPit): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_PIT_UPDATE"] = 1410] = "PRE_GRID_ENTITY_PIT_UPDATE";
    /**
     * Fires after the pit grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPitUpdate(pit: GridEntityPit): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_PIT_UPDATE"] = 1411] = "POST_GRID_ENTITY_PIT_UPDATE";
    /**
     * Fires before the poop grid entity updates. Return false to cancel the update.
     *
     * This callback does not include the EntityNPC poops used by Tainted Blue Baby.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPoopUpdate(poop: GridEntityPoop): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_POOP_UPDATE"] = 1412] = "PRE_GRID_ENTITY_POOP_UPDATE";
    /**
     * Fires after the poop grid entity updates.
     *
     * This callback does not include the EntityNPC poops used by Tainted Blue Baby.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPoopUpdate(poop: GridEntityPoop): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_POOP_UPDATE"] = 1413] = "POST_GRID_ENTITY_POOP_UPDATE";
    /**
     * Fires before the pressure plate grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPressurePlateUpdate(
     *   pressurePlate: GridEntityPressurePlate
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_PRESSURE_PLATE_UPDATE"] = 1414] = "PRE_GRID_ENTITY_PRESSURE_PLATE_UPDATE";
    /**
     * Fires after the pressure plate grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPressurePlateUpdate(pressurePlate: GridEntityPressurePlate): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_PRESSURE_PLATE_UPDATE"] = 1415] = "POST_GRID_ENTITY_PRESSURE_PLATE_UPDATE";
    /**
     * Fires before the rock grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityRockUpdate(rock: GridEntityRock): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_ROCK_UPDATE"] = 1416] = "PRE_GRID_ENTITY_ROCK_UPDATE";
    /**
     * Fires after the rock grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityRockUpdate(rock: GridEntityRock): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_ROCK_UPDATE"] = 1417] = "POST_GRID_ENTITY_ROCK_UPDATE";
    /**
     * Fires before the spikes grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntitySpikesUpdate(spikes: GridEntitySpikes): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_SPIKES_UPDATE"] = 1418] = "PRE_GRID_ENTITY_SPIKES_UPDATE";
    /**
     * Fires after the spikes grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntitySpikesUpdate(spikes: GridEntitySpikes): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_SPIKES_UPDATE"] = 1419] = "POST_GRID_ENTITY_SPIKES_UPDATE";
    /**
     * Fires before the staircase grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityStaircaseUpdate(stairCase: GridEntityStaircase): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_STAIRCASE_UPDATE"] = 1420] = "PRE_GRID_ENTITY_STAIRCASE_UPDATE";
    /**
     * Fires after the staircase grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityStaircaseUpdate(stairCase: GridEntityStaircase): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_STAIRCASE_UPDATE"] = 1421] = "POST_GRID_ENTITY_STAIRCASE_UPDATE";
    /**
     * Fires before the statue grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityStatueUpdate(statue: GridEntityStatue): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_STATUE_UPDATE"] = 1422] = "PRE_GRID_ENTITY_STATUE_UPDATE";
    /**
     * Fires after the statue grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityStatueUpdate(statue: GridEntityStatue): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_STATUE_UPDATE"] = 1423] = "POST_GRID_ENTITY_STATUE_UPDATE";
    /**
     * Fires before the teleporter grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTeleporterUpdate(
     *   teleporter: GridEntityTeleporter
     * ): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_TELEPORTER_UPDATE"] = 1424] = "PRE_GRID_ENTITY_TELEPORTER_UPDATE";
    /**
     * Fires after the teleporter grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTeleporterUpdate(
     *   teleporter: GridEntityTeleporter
     * ): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_TELEPORTER_UPDATE"] = 1425] = "POST_GRID_ENTITY_TELEPORTER_UPDATE";
    /**
     * Fires before the trapdoor grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityTrapdoorUpdate(trapdoor: GridEntityTrapdoor): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_TRAPDOOR_UPDATE"] = 1426] = "PRE_GRID_ENTITY_TRAPDOOR_UPDATE";
    /**
     * Fires after the trapdoor grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTrapdoorUpdate(trapdoor: GridEntityTrapdoor): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_TRAPDOOR_UPDATE"] = 1427] = "POST_GRID_ENTITY_TRAPDOOR_UPDATE";
    /**
     * Fires before the web grid entity updates. Return false to cancel the update.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityWebUpdate(web: GridEntityWeb): boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_WEB_UPDATE"] = 1428] = "PRE_GRID_ENTITY_WEB_UPDATE";
    /**
     * Fires after the web grid entity updates.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityWebUpdate(web: GridEntityWeb): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_WEB_UPDATE"] = 1429] = "POST_GRID_ENTITY_WEB_UPDATE";
    /**
     * Fires before the spikes grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntitySpikesRender(
     *   grid: GridEntitySpikes,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_SPIKES_RENDER"] = 1432] = "PRE_GRID_ENTITY_SPIKES_RENDER";
    /**
     * Fires after the spikes grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntitySpikesRender(grid: GridEntitySpikes): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_SPIKES_RENDER"] = 1433] = "POST_GRID_ENTITY_SPIKES_RENDER";
    /**
     * Fires before the web grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityWebRender(
     *   grid: GridEntityWeb,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_WEB_RENDER"] = 1434] = "PRE_GRID_ENTITY_WEB_RENDER";
    /**
     * Fires after the web grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityWebRender(grid: GridEntityWeb): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_WEB_RENDER"] = 1435] = "POST_GRID_ENTITY_WEB_RENDER";
    /**
     * Fires after the TNT grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityTNTRender(
     *   grid: GridEntityTNT,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_TNT_RENDER"] = 1436] = "PRE_GRID_ENTITY_TNT_RENDER";
    /**
     * Fires after the TNT grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTNTRender(grid: GridEntityTNT): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_TNT_RENDER"] = 1437] = "POST_GRID_ENTITY_TNT_RENDER";
    /**
     * Fires before the trapdoor grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityTrapdoorRender(
     *   grid: GridEntityTrapdoor,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_TRAPDOOR_RENDER"] = 1438] = "PRE_GRID_ENTITY_TRAPDOOR_RENDER";
    /**
     * Fires after the trapdoor grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTrapdoorRender(grid: GridEntityTrapdoor): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_TRAPDOOR_RENDER"] = 1439] = "POST_GRID_ENTITY_TRAPDOOR_RENDER";
    /**
     * Fires before the staircase grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityStaircaseRender(
     *   grid: GridEntityStaircase,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_STAIRCASE_RENDER"] = 1440] = "PRE_GRID_ENTITY_STAIRCASE_RENDER";
    /**
     * Fires after the staircase grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityStaircaseRender(grid: GridEntityStaircase): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_STAIRCASE_RENDER"] = 1441] = "POST_GRID_ENTITY_STAIRCASE_RENDER";
    /**
     * Fires before the decoration grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityDecorationRender(
     *   grid: GridEntityDecoration,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_DECORATION_RENDER"] = 1444] = "PRE_GRID_ENTITY_DECORATION_RENDER";
    /**
     * Fires after the decoration grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityDecorationRender(grid: GridEntityDecoration): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_DECORATION_RENDER"] = 1445] = "POST_GRID_ENTITY_DECORATION_RENDER";
    /**
     * Fires before the door grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityDoorRender(
     *   grid: GridEntityDoor,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_DOOR_RENDER"] = 1446] = "PRE_GRID_ENTITY_DOOR_RENDER";
    /**
     * Fires after the door grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityDoorRender(grid: GridEntityDoor): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_DOOR_RENDER"] = 1447] = "POST_GRID_ENTITY_DOOR_RENDER";
    /**
     * Fires before the staircase grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityFireRender(
     *   grid: GridEntityFire,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_FIRE_RENDER"] = 1448] = "PRE_GRID_ENTITY_FIRE_RENDER";
    /**
     * Fires after the staircase grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityFireRender(grid: GridEntityFire): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_FIRE_RENDER"] = 1449] = "POST_GRID_ENTITY_FIRE_RENDER";
    /**
     * Fires before the lock grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityLockRender(
     *   grid: GridEntityLock,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_LOCK_RENDER"] = 1450] = "PRE_GRID_ENTITY_LOCK_RENDER";
    /**
     * Fires after the lock grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityLockRender(grid: GridEntityLock): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_LOCK_RENDER"] = 1451] = "POST_GRID_ENTITY_LOCK_RENDER";
    /**
     * Fires before the teleporter grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityTeleporterRender(
     *   grid: GridEntityTeleporter,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_TELEPORTER_RENDER"] = 1452] = "PRE_GRID_ENTITY_TELEPORTER_RENDER";
    /**
     * Fires after the teleporter grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityTeleporterRender(grid: GridEntityTeleporter): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_TELEPORTER_RENDER"] = 1453] = "POST_GRID_ENTITY_TELEPORTER_RENDER";
    /**
     * Fires before the pit grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPitRender(
     *   grid: GridEntityPit,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_PIT_RENDER"] = 1454] = "PRE_GRID_ENTITY_PIT_RENDER";
    /**
     * Fires after the pit grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPitRender(grid: GridEntityPit): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_PIT_RENDER"] = 1455] = "POST_GRID_ENTITY_PIT_RENDER";
    /**
     * Fires before the poop grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPoopRender(
     *   grid: GridEntityPoop,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_POOP_RENDER"] = 1456] = "PRE_GRID_ENTITY_POOP_RENDER";
    /**
     * Fires after the poop grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPoopRender(grid: GridEntityPoop): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_POOP_RENDER"] = 1457] = "POST_GRID_ENTITY_POOP_RENDER";
    /**
     * Fires before the rock grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityRockRender(
     *   grid: GridEntityRock,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_ROCK_RENDER"] = 1458] = "PRE_GRID_ENTITY_ROCK_RENDER";
    /**
     * Fires after the rock grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityRockRender(grid: GridEntityRock): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_ROCK_RENDER"] = 1459] = "POST_GRID_ENTITY_ROCK_RENDER";
    /**
     * Fires before the pressure plate grid entity renders. Return a Vector to modify the render
     * offset. Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityPressurePlateRender(
     *   grid: GridEntityPressurePlate,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_PRESSURE_PLATE_RENDER"] = 1460] = "PRE_GRID_ENTITY_PRESSURE_PLATE_RENDER";
    /**
     * Fires after the pressure plate grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function postGridEntityPressurePlateRender(grid: GridEntityPressurePlate): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_PRESSURE_PLATE_RENDER"] = 1461] = "POST_GRID_ENTITY_PRESSURE_PLATE_RENDER";
    /**
     * Fires before the wall grid entity renders. Return a Vector to modify the render offset.
     * Alternatively, return false to cancel the rendering.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityWallRender(
     *   grid: GridEntityWall,
     *   offset: Vector
     * ): Vector | boolean | undefined {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["PRE_GRID_ENTITY_WALL_RENDER"] = 1462] = "PRE_GRID_ENTITY_WALL_RENDER";
    /**
     * Fires after the wall grid entity renders.
     *
     * When registering the callback with the `addCallbackRepentogon` method:
     * - You can provide an optional third argument that will make the callback only fire if it
     *   matches the `GridEntityType` provided.
     *
     * ```ts
     * function preGridEntityWallRender(grid: GridEntityWall): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_GRID_ENTITY_WALL_RENDER"] = 1463] = "POST_GRID_ENTITY_WALL_RENDER";
    /**
     * Fires after a save slot is loaded by the game.
     *
     * - The `saveSlot` parameter is the slot you should care about.
     * - The `isSlotSelected` parameter indicates if the slot is being loaded has been actually
     *   selected from the save menu screen.
     * - The `rawSlot` parameter is the actual save slot the game uses, not the one the API uses since
     *   it can be 0!
     *
     * ```ts
     * function postSaveSlotLoad(saveSlot: int, isSlotSelected: boolean, rawSlot: int): void {}
     * ```
     */
    ModCallbackRepentogon[ModCallbackRepentogon["POST_SAVE_SLOT_LOAD"] = 1470] = "POST_SAVE_SLOT_LOAD";
})(ModCallbackRepentogon || (exports.ModCallbackRepentogon = ModCallbackRepentogon = {}));
